@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.9100';
+our $VERSION = '0.9101';
 
 use warnings;
 use strict;
@@ -46,9 +46,7 @@ sub populate {
                     $self->set_vertex_attribute($vertex, $entry, $label);
                 }
             }
-            $self->_from_hash(
-                $vertex, $data->{$vertex}, $attr
-            );
+            $self->_from_hash( $vertex, $data->{$vertex}, $attr );
         }
     }
     else {
@@ -65,7 +63,7 @@ sub _from_array {
     # Make nodes and edges.
     for my $n (0 .. @$neighbors - 1) {
         my $w = $neighbors->[$n]; # Weight of the edge to the neighbor.
-        next unless $w; # TODO Skip zero weight nodes if requested?
+        next unless $w; # Skip zero weight nodes
 
         # Add a node-node edge to the graph.
         $self->add_edge($vertex, $n);
@@ -194,7 +192,7 @@ sub edge_span {
 sub path_cost {
     my ($self, $path, $attr) = @_;
 
-    return unless $self->has_path( @$path );
+    return undef unless $self->has_path( @$path );
 
     my $path_cost = 0;
 
@@ -224,7 +222,7 @@ sub MST_edge_sum {
 
 sub dump {
     my $self = shift;
-    my $attr = shift || 'weight';
+    my $attr = shift || WEIGHT;
 
     for my $vertex ( sort { $a <=> $b } $self->vertices ) {
         my $label = $self->get_vertex_attribute($vertex, 'label');
@@ -256,7 +254,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.9100
+version 0.9101
 
 =head1 SYNOPSIS
 
@@ -299,14 +297,14 @@ version 0.9100
 =head1 DESCRIPTION
 
 A C<Graph::Weighted> object is a subclass of the L<Graph> module with attribute
-handling.  As such, all of the L<Graph> methods may be used, with the addition
-of custom weighting.
+handling.  As such, all of the L<Graph> methods may be used.
 
 =head1 METHODS
 
 =head2 new
 
   my $gw = Graph::Weighted->new;
+  my $gw = Graph::Weighted->new(%arguments);
 
 Return a new C<Graph::Weighted> object.
 
@@ -321,13 +319,13 @@ Please see L<Graph/Constructors> for the possible constructor arguments.
   $gw->populate(\%data_points);
   $gw->populate(\%data_points, $attribute);
 
-Populate a graph with weighted nodes.
+Populate a graph with weighted nodes and edges.
 
 The data can be an arrayref of numeric vectors, a C<Math::Matrix> object, a
-C<Math::MatrixReal> object, or a hashref of edge values.
+C<Math::MatrixReal> object, or a hashref of node-edge values.
 
-Data given as a hash reference may also contain multiple node labels.  Also, the
-keys need not be numeric, just unique.
+Data given as a hash reference may also contain node labels.  Also, the keys
+need not be numeric, just unique.
 
 The optional C<attribute> argument is a string with the default C<weight>.
 
@@ -362,9 +360,6 @@ Return the lightest and heaviest edges as array references.
 
 Return the summed weight (or cost attribute) of the path edges.
 
-For the cost of the shortest path, please see C<path_length> under
-L<Graph/"All-Pairs Shortest Paths (APSP)">.
-
 =head2 MST_edge_sum
 
   $sum = $gw->MST_edge_sum($tree);
